package com.link.core.util;

import com.link.core.basic.service.BasicServiceException;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;
import java.security.SecureRandom;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.concurrent.ConcurrentHashMap;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import java.util.zip.ZipOutputStream;
import javax.annotation.Nullable;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.KeyManager;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class CommonTools {
   private static final Logger logger = LoggerFactory.getLogger(CommonTools.class);
   public static final String WEB_DIR = "/web/file/";

   public static <T> T notBlank(@Nullable T str, String errorMsg) {
      if (str == null) {
         throw new BasicServiceException(errorMsg);
      } else if (StringUtils.isBlank(str.toString())) {
         throw new IllegalArgumentException(errorMsg);
      } else {
         return str;
      }
   }

   public static File downloadByUrl(String fileUrl) {
      if (StringUtils.isBlank(fileUrl)) {
         throw new BasicServiceException("请传入附件下载链接");
      } else if (fileUrl.startsWith("http://")) {
         return downloadByHttp(fileUrl);
      } else if (fileUrl.startsWith("https://")) {
         return downloadByHttps(fileUrl);
      } else {
         logger.info("未识别的网络协议，附件下载链接：" + fileUrl);
         throw new BasicServiceException("未识别的网络协议");
      }
   }

   public static synchronized File downloadByHttp(String fileUrl) {
      File file = newAttachmentWithUrl(fileUrl);
      if (file.exists()) {
         return file;
      } else {
         DataInputStream dis = null;
         DataOutputStream dos = null;

         try {
            URL url = new URL(fileUrl);
            dis = new DataInputStream(url.openStream());
            dos = new DataOutputStream(new FileOutputStream(file));
            byte[] bytes = new byte[8192];

            int len;
            while((len = dis.read(bytes)) != -1) {
               dos.write(bytes, 0, len);
            }

            File var7 = file;
            return var7;
         } catch (IOException var11) {
            IOException e = var11;
            e.printStackTrace();
            boolean delete = file.delete();
            logger.info("[downloadByHttp]下载附件异常：{} 删除已创建的附件{}", e.getMessage(), file.getAbsolutePath());
            throw new BasicServiceException("下载附件异常，请稍后再试");
         } finally {
            closeStream(dis, dos);
         }
      }
   }

   public static synchronized File downloadByHttps(String fileUrl) {
      File file = newAttachmentWithUrl(fileUrl);
      if (file.exists()) {
         return file;
      } else {
         DataInputStream dis = null;
         DataOutputStream dos = null;

         try {
            SSLContext sslContext = SSLContext.getInstance("SSL", "SunJSSE");
            sslContext.init((KeyManager[])null, new TrustManager[]{new X509TrustUtil()}, new SecureRandom());
            URL url = new URL(fileUrl);
            HostnameVerifier ignorHostNameVerifier = (s, sslSession) -> {
               return true;
            };
            HttpsURLConnection.setDefaultHostnameVerifier(ignorHostNameVerifier);
            HttpsURLConnection.setDefaultSSLSocketFactory(sslContext.getSocketFactory());
            HttpsURLConnection urlConnection = (HttpsURLConnection)url.openConnection();
            urlConnection.setConnectTimeout(30000);
            urlConnection.setReadTimeout(30000);
            int code = urlConnection.getResponseCode();
            if (code != 200) {
               throw new Exception("文件读取失败");
            }

            dis = new DataInputStream(urlConnection.getInputStream());
            dos = new DataOutputStream(new FileOutputStream(file));
            byte[] bytes = new byte[8192];

            int len;
            while((len = dis.read(bytes)) != -1) {
               dos.write(bytes, 0, len);
            }
         } catch (Exception var14) {
            Exception e = var14;
            e.printStackTrace();
         } finally {
            closeStream(dis, dos);
         }

         return file;
      }
   }

   public static File newAttachmentWithUrl(String fileUrl) {
      String relativePath = fileUrl.substring(fileUrl.indexOf("/web/file/"));
      String absolutePath = CoreYmlConstants.getPortalShareFileDir() + relativePath;
      File file = new File(absolutePath);
      if (!file.getParentFile().exists()) {
         boolean mkdirs = file.getParentFile().mkdirs();
         if (!mkdirs) {
            logger.info("[downloadByHttp]下载附件异常：创建上级文件夹失败");
            throw new BasicServiceException("下载附件异常：创建上级文件夹失败");
         }
      }

      return file;
   }

   private static void closeStream(InputStream dis, OutputStream dos) {
      IOException e;
      if (dis != null) {
         try {
            dis.close();
         } catch (IOException var4) {
            e = var4;
            e.printStackTrace();
         }
      }

      if (dos != null) {
         try {
            dos.close();
         } catch (IOException var3) {
            e = var3;
            e.printStackTrace();
         }
      }

   }

   public static void zipCompress(File[] input, File output) throws IOException {
      ZipOutputStream zos = new ZipOutputStream(new FileOutputStream(output));
      Throwable var3 = null;

      try {
         BufferedOutputStream bos = new BufferedOutputStream(zos);
         Throwable var5 = null;

         try {
            ConcurrentHashMap<String, Integer> occur = new ConcurrentHashMap(input.length);
            File[] var7 = input;
            int var8 = input.length;

            for(int var9 = 0; var9 < var8; ++var9) {
               File file = var7[var9];
               compress(zos, bos, file, (String)null, occur);
            }
         } catch (Throwable var32) {
            var5 = var32;
            throw var32;
         } finally {
            if (bos != null) {
               if (var5 != null) {
                  try {
                     bos.close();
                  } catch (Throwable var31) {
                     var5.addSuppressed(var31);
                  }
               } else {
                  bos.close();
               }
            }

         }
      } catch (Throwable var34) {
         var3 = var34;
         throw var34;
      } finally {
         if (zos != null) {
            if (var3 != null) {
               try {
                  zos.close();
               } catch (Throwable var30) {
                  var3.addSuppressed(var30);
               }
            } else {
               zos.close();
            }
         }

      }

   }

   public static void zipCompress(File[] input, HttpServletResponse response) throws IOException {
      ZipOutputStream zos = new ZipOutputStream(response.getOutputStream());
      Throwable var3 = null;

      try {
         BufferedOutputStream bos = new BufferedOutputStream(zos);
         Throwable var5 = null;

         try {
            ConcurrentHashMap<String, Integer> occur = new ConcurrentHashMap(input.length);
            File[] var7 = input;
            int var8 = input.length;

            for(int var9 = 0; var9 < var8; ++var9) {
               File file = var7[var9];
               compress(zos, bos, file, file.getName(), occur);
               response.flushBuffer();
            }
         } catch (Throwable var32) {
            var5 = var32;
            throw var32;
         } finally {
            if (bos != null) {
               if (var5 != null) {
                  try {
                     bos.close();
                  } catch (Throwable var31) {
                     var5.addSuppressed(var31);
                  }
               } else {
                  bos.close();
               }
            }

         }
      } catch (Throwable var34) {
         var3 = var34;
         throw var34;
      } finally {
         if (zos != null) {
            if (var3 != null) {
               try {
                  zos.close();
               } catch (Throwable var30) {
                  var3.addSuppressed(var30);
               }
            } else {
               zos.close();
            }
         }

      }

   }

   public static void compress(ZipOutputStream zos, BufferedOutputStream bos, File input, String name, ConcurrentHashMap<String, Integer> occur) throws IOException {
      if (input != null && input.exists()) {
         if (StringUtils.isBlank(name)) {
            name = input.getName();
         }

         int newValue = (Integer)occur.merge(name, 1, Integer::sum);
         if (newValue > 1) {
            StringBuilder builder = new StringBuilder(name);
            builder.insert(builder.lastIndexOf("."), newValue - 1);
            name = builder.toString();
         }

         int len;
         if (input.isDirectory()) {
            File[] listFiles = input.listFiles();
            if (listFiles != null && listFiles.length != 0) {
               File[] var7 = listFiles;
               int var8 = listFiles.length;

               for(len = 0; len < var8; ++len) {
                  File file = var7[len];
                  String fileName = name + File.separator + file.getName();
                  compress(zos, bos, file, fileName, occur);
                  occur.merge(fileName, 1, (a, b) -> {
                     return a - b;
                  });
               }
            } else {
               zos.putNextEntry(new ZipEntry(name + File.separator));
               zos.closeEntry();
            }
         } else {
            zos.putNextEntry(new ZipEntry(name));
            FileInputStream fis = new FileInputStream(input);
            BufferedInputStream bis = new BufferedInputStream(fis);
            byte[] bytes = new byte[1024];

            while((len = bis.read(bytes)) != -1) {
               bos.write(bytes, 0, len);
            }

            bis.close();
            bos.flush();
            zos.closeEntry();
         }

      }
   }

   public static void zipUnCompress(File inputZip, String destFilePath) throws IOException {
      if (!inputZip.exists()) {
         throw new FileNotFoundException("未找到压缩包 " + inputZip);
      } else {
         ZipInputStream zis = new ZipInputStream(new FileInputStream(inputZip));
         Throwable var3 = null;

         try {
            ZipEntry zipEntry;
            try {
               while((zipEntry = zis.getNextEntry()) != null) {
                  if (!zipEntry.isDirectory()) {
                     File file = new File(destFilePath, zipEntry.getName());
                     if (!file.exists()) {
                        boolean var6 = (new File(file.getParent())).mkdirs();
                     }

                     BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(file));
                     Throwable var7 = null;

                     try {
                        byte[] bytes = new byte[1024];

                        int len;
                        while((len = zis.read(bytes)) != -1) {
                           bos.write(bytes, 0, len);
                        }
                     } catch (Throwable var31) {
                        var7 = var31;
                        throw var31;
                     } finally {
                        if (bos != null) {
                           if (var7 != null) {
                              try {
                                 bos.close();
                              } catch (Throwable var30) {
                                 var7.addSuppressed(var30);
                              }
                           } else {
                              bos.close();
                           }
                        }

                     }
                  }
               }
            } catch (Throwable var33) {
               var3 = var33;
               throw var33;
            }
         } finally {
            if (zis != null) {
               if (var3 != null) {
                  try {
                     zis.close();
                  } catch (Throwable var29) {
                     var3.addSuppressed(var29);
                  }
               } else {
                  zis.close();
               }
            }

         }

      }
   }

   private static class X509TrustUtil implements X509TrustManager {
      private X509TrustUtil() {
      }

      public void checkClientTrusted(X509Certificate[] x509Certificates, String s) throws CertificateException {
      }

      public void checkServerTrusted(X509Certificate[] x509Certificates, String s) throws CertificateException {
      }

      public X509Certificate[] getAcceptedIssuers() {
         return new X509Certificate[0];
      }

      // $FF: synthetic method
      X509TrustUtil(Object x0) {
         this();
      }
   }
}
